Get the number of common shares outstanding for a company.
sfa_load_common_shares_outstanding(
id = NULL,
ticker = NULL,
start = NULL,
end = NULL,
api_key = getOption("sfa_api_key"),
cache_dir = getOption("sfa_cache_dir")
)data.table containing the common shares outstanding.
integer 'SimFin' IDs of the companies of interest. Any
id will be internally translated to the respective ticker. This
reduces the number of queries in case you query the same company via
ticker and id.
integer Ticker of the companies of interest.
Date Filter for the report dates (reserved for SimFin+ users). With this filter you can filter the statements by the date on which the reported period ended ('Report Date'). By specifying a value here, only statements will be retrieved with report dates ending AFTER the specified date.
Date Filter for the report dates (reserved for SimFin+ users). With this filter you can filter the statements by the date on which the reported period ended ('Report Date'). By specifying a value here, only statements will be retrieved with report dates ending BEFORE the specified date.
character Your 'SimFin' API key. It's recommended to set the API key globally using sfa_set_api_key.
character Your cache directory. It's recommended to set the cache directory globally using sfa_set_cache_dir.