Get the number of weighted shares outstanding for a company.
sfa_load_weighted_shares_outstanding(
id = NULL,
ticker = NULL,
fyear = NULL,
period = NULL,
start = NULL,
end = NULL,
ttm = NULL,
api_key = getOption("sfa_api_key"),
cache_dir = getOption("sfa_cache_dir")
)data.table containing the common shares outstanding.
integer 'SimFin' IDs of the companies of interest. Any
id will be internally translated to the respective ticker. This
reduces the number of queries in case you query the same company via
ticker and id.
integer Ticker of the companies of interest.
integer Filter for fiscal year. As a non-SimFin+ user, you have to provide exactly one fiscal year. As SimFin+ user, this filter can be omitted to retrieve all data available for the company.
character Filter for periods. As a non-SimFin+ user, you have to provide exactly one period. As SimFin+ user, this filter can be omitted to retrieve all statements available for the company.
'q1': First fiscal quarter.
'q2': Second fiscal quarter.
'q3': Third fiscal quarter.
'q4': Fourth fiscal quarter.
'fy': Full fiscal year.
'h1': First 6 months of fiscal year.
'h2': Last 6 months of fiscal year.
'9m': First nine months of fiscal year.
'6m': Any fiscal 6 month period (first + second half years; reserved
for SimFin+ users).
'quarters': All quarters (q1 + q2 + q3 + q4; reserved for SimFin+
users).
Date Filter for the report dates (reserved for SimFin+ users). With this filter you can filter the statements by the date on which the reported period ended ('Report Date'). By specifying a value here, only statements will be retrieved with report dates ending AFTER the specified date.
Date Filter for the report dates (reserved for SimFin+ users). With this filter you can filter the statements by the date on which the reported period ended ('Report Date'). By specifying a value here, only statements will be retrieved with report dates ending BEFORE the specified date.
logical If TRUE, retrieves trailing twelve month periods.
character Your 'SimFin' API key. It's recommended to set the API key globally using sfa_set_api_key.
character Your cache directory. It's recommended to set the cache directory globally using sfa_set_cache_dir.